---
title: search
description: how to search for files and folders in rovr.
---

`rovr` provides a fuzzy search functionality to quickly find items in the file list and pinned sidebar.

### how to use search

1.  focus the file list or pinned sidebar.
2.  press `/` or `ctrl+f` to focus the search bar for that panel.
3.  start typing your search query.

the list will be filtered in real-time to show only the items that match your query.

### fuzzy matching

the search uses fuzzy matching, which means you don't have to type the exact name of the file or folder. the characters in your search query just need to appear in the item's name in the same order.

for example, to find `any_file_that_you_could_think_of.txt`, you could type:

- `ayc`
- `aftyctot`
- `______.`

and it will still be matched.

### exiting search

to exit the search box, just press `esc`.
